==> symfony_7.4.0~rc2+dfsg.orig.tar.xz: symfony-7.4.0~rc2/src/Symfony/Component/Intl/Resources/data/regions/ie.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosovo',
    ],
    'Names' => [
        'AL' => 'Albania',
        'AQ' => 'Antarctica',
        'AT' => 'Austria',
        'BA' => 'Bosnia e Herzegovina',
        'BE' => 'Belgia',
        'BG' => 'Bulgaria',
        'CH' => 'Svissia',
        'CZ' => 'Tchekia',
        'DE' => 'Germania',
        'DK' => 'Dania',
        'EE' => 'Estonia',
        'ER' => 'Eritrea',
        'ES' => 'Hispania',
        'ET' => 'Etiopia',
        'FI' => 'Finland',
        'FJ' => 'Fidji',
        'FR' => 'Francia',
        'GB' => 'Unit Reyia',
        'GR' => 'Grecia',
        'GY' => 'Guyana',
        'HR' => 'Croatia',
        'HU' => 'Hungaria',
        'ID' => 'Indonesia',
        'IE' => 'Irland',
        'IN' => 'India',
        'IR' => 'Iran',
        'IS' => 'Island',
        'IT' => 'Italia',
        'KH' => 'Cambodja',
        'LK' => 'Sri-Lanka',
        'LU' => 'Luxemburg',
        'MC' => 'Mónaco',
        'ME' => 'Montenegro',
        'MK' => 'Nord-Macedonia',
        'MQ' => 'Martinica',
        'MT' => 'Malta',
        'MU' => 'Mauricio',
        'MV' => 'Maldivas',
        'NF' => 'Insul Norfolk',
        'NR' => 'Nauru',
        'NZ' => 'Nov-Zeland',
        'PE' => 'Perú',
        'PH' => 'Filipines',
        'PK' => 'Pakistan',
        'PL' => 'Polonia',
        'PR' => 'Porto-Rico',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'RO' => 'Rumania',
        'RS' => 'Serbia',
        'RU' => 'Russia',
        'SE' => 'Svedia',
        'SI' => 'Slovenia',
        'SK' => 'Slovakia',
        'SM' => 'San-Marino',
        'SX' => 'Sint-Maarten',
        'TC' => 'Turks e Caicos',
        'TD' => 'Tchad',
        'TK' => 'Tokelau',
        'TL' => 'Ost-Timor',
        'TT' => 'Trinidad e Tobago',
        'TV' => 'Tuvalu',
        'UA' => 'Ukraina',
        'VU' => 'Vanuatu',
        'WS' => 'Samoa',
    ],
];

==> symfony_8.0.2+dfsg.orig.tar.xz: symfony-8.0.2/src/Symfony/Component/Intl/Resources/data/regions/ie.php <==
<?php

return [
    'UserAssignedNames' => [
        'XK' => 'Kosovo',
    ],
    'Names' => [
        'AD' => 'Andorra',
        'AL' => 'Albania',
        'AQ' => 'Antarctica',
        'AT' => 'Austria',
        'AX' => 'Insules Åland',
        'BA' => 'Bosnia e Herzegovina',
        'BE' => 'Belgia',
        'BG' => 'Bulgaria',
        'BY' => 'Bielorussia',
        'CH' => 'Svissia',
        'CZ' => 'Tchekia',
        'DE' => 'Germania',
        'DK' => 'Dania',
        'EE' => 'Estonia',
        'ER' => 'Eritrea',
        'ES' => 'Hispania',
        'ET' => 'Etiopia',
        'FI' => 'Finland',
        'FJ' => 'Fidji',
        'FR' => 'Francia',
        'GB' => 'Unit Reyia',
        'GG' => 'Guernsey',
        'GI' => 'Gibraltar',
        'GR' => 'Grecia',
        'GY' => 'Guyana',
        'HR' => 'Croatia',
        'HU' => 'Hungaria',
        'ID' => 'Indonesia',
        'IE' => 'Irland',
        'IM' => 'Insul de Man',
        'IN' => 'India',
        'IR' => 'Iran',
        'IS' => 'Island',
        'IT' => 'Italia',
        'JE' => 'Jersey',
        'KH' => 'Cambodja',
        'LI' => 'Liechtenstein',
        'LK' => 'Sri-Lanka',
        'LT' => 'Lituania',
        'LU' => 'Luxemburg',
        'LV' => 'Lettonia',
        'MC' => 'Mónaco',
        'MD' => 'Moldova',
        'ME' => 'Montenegro',
        'MK' => 'Nord-Macedonia',
        'MQ' => 'Martinica',
        'MT' => 'Malta',
        'MU' => 'Mauricio',
        'MV' => 'Maldivas',
        'NF' => 'Insul Norfolk',
        'NL' => 'Nederland',
        'NO' => 'Norvegia',
        'NR' => 'Nauru',
        'NZ' => 'Nov-Zeland',
        'PE' => 'Perú',
        'PH' => 'Filipines',
        'PK' => 'Pakistan',
        'PL' => 'Polonia',
        'PR' => 'Porto-Rico',
        'PT' => 'Portugal',
        'PW' => 'Palau',
        'RO' => 'Rumania',
        'RS' => 'Serbia',
        'RU' => 'Russia',
        'SE' => 'Svedia',
        'SI' => 'Slovenia',
        'SJ' => 'Svalbard e Jan Mayen',
        'SK' => 'Slovakia',
        'SM' => 'San-Marino',
        'SX' => 'Sint-Maarten',
        'TC' => 'Turks e Caicos',
        'TD' => 'Tchad',
        'TK' => 'Tokelau',
        'TL' => 'Ost-Timor',
        'TT' => 'Trinidad e Tobago',
        'TV' => 'Tuvalu',
        'UA' => 'Ukraina',
        'VA' => 'Cité de Vatican',
        'VU' => 'Vanuatu',
        'WS' => 'Samoa',
    ],
];
